@@ -2,7 +2,7 @@ package Data::Stag::IndentWriter;
 
 =head1 NAME
 
-  Data::Stag::IndentWriter
+  Data::Stag::IndentWriter - writes stag events into stag indent format
 
 =head1 SYNOPSIS
 
@@ -20,7 +20,7 @@ use base qw(Data::Stag::Writer);
 use Carp;
 
 use vars qw($VERSION);
-$VERSION="0.10";
+$VERSION="0.13";
 
 sub fmtstr {
     return 'indent';
