@@ -1,4 +1,4 @@
-# $Id: StagImpl.pm,v 1.63 2005/12/16 17:42:44 cmungall Exp $
+# $Id: StagImpl.pm,v 1.67 2008/06/05 06:17:51 cmungall Exp $
 #
 # Author: Chris Mungall <cjm@fruitfly.org>
 #
@@ -8,7 +8,7 @@ package Data::Stag::StagImpl;
 
 =head1 NAME
 
-  Data::Stag::StagImpl
+  Data::Stag::StagImpl - default implementation for Data::Stag
 
 =head1 SYNOPSIS
 
@@ -30,7 +30,7 @@ use Data::Stag::Util qw(rearrange);
 use base qw(Data::Stag::StagI);
 
 use vars qw($VERSION);
-$VERSION="0.10";
+$VERSION="0.13";
 
 
 sub new {
@@ -363,6 +363,9 @@ sub _gethandlerobj {
     elsif ($fmt =~ /perl/i) {
         $writer = "Data::Stag::PerlWriter";
     }
+    elsif ($fmt =~ /json/i) {
+        $writer = "Data::Stag::JSONWriter";
+    }
     elsif ($fmt =~ /dtd/i) {
         $writer = "Data::Stag::DTDWriter";
     }
@@ -1496,6 +1499,33 @@ sub paste {
     return;
 }
 
+# 
+sub maptree {
+    my $tree = shift;
+    my $code = shift;
+    my $parent = shift;
+    my $next = $code->($tree, $parent);
+    if ($next) {
+        if (ref($next) && ref($next) eq 'ARRAY') {
+            return @$next;
+        }
+        my $elt = $next->element;
+        my @subnodes = subnodes($next);
+        if (!@subnodes) {
+            return $next;
+        }
+        my @new_subnodes = ();
+        foreach (@subnodes) {
+            my @nu = maptree($_, $code, $tree);
+            push(@new_subnodes,@nu);
+        }
+        return Data::Stag->new($elt=>[@new_subnodes]);
+    }
+    else {
+        return ();
+    }
+}
+
 # iterate depth first through tree executing code
 sub iterate {
     my $tree = shift;
