@@ -2,7 +2,7 @@ package Data::Stag::null;
 
 =head1 NAME
 
-  Data::Stag::Arr2HTML
+  Data::Stag::Arr2HTML - null
 
 =head1 SYNOPSIS
 
@@ -19,7 +19,7 @@ use strict;
 use base qw(Data::Stag::BaseHandler);
 
 use vars qw($VERSION);
-$VERSION="0.10";
+$VERSION="0.13";
 
 sub start_event {}
 sub end_event {}
